@@ -39,11 +39,13 @@ G_DEFINE_ABSTRACT_TYPE (GClueLocationSource, gclue_location_source, G_TYPE_OBJEC
 
 struct _GClueLocationSourcePrivate
 {
-        GeocodeLocation *location;
+        GClueLocation *location;
 
         guint active_counter;
 
         GClueAccuracyLevel avail_accuracy_level;
+
+        gboolean compute_movement;
 };
 
 enum
@@ -52,6 +54,7 @@ enum
         PROP_LOCATION,
         PROP_ACTIVE,
         PROP_AVAILABLE_ACCURACY_LEVEL,
+        PROP_COMPUTE_MOVEMENT,
         LAST_PROP
 };
 
@@ -79,6 +82,10 @@ gclue_location_source_get_property (GObject    *object,
                 g_value_set_enum (value, source->priv->avail_accuracy_level);
                 break;
 
+        case PROP_COMPUTE_MOVEMENT:
+                g_value_set_boolean (value, source->priv->compute_movement);
+                break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         }
@@ -95,7 +102,7 @@ gclue_location_source_set_property (GObject      *object,
         switch (prop_id) {
         case PROP_LOCATION:
         {
-                GeocodeLocation *location = g_value_get_object (value);
+                GClueLocation *location = g_value_get_object (value);
 
                 gclue_location_source_set_location (source, location);
                 break;
@@ -105,6 +112,10 @@ gclue_location_source_set_property (GObject      *object,
                 source->priv->avail_accuracy_level = g_value_get_enum (value);
                 break;
 
+        case PROP_COMPUTE_MOVEMENT:
+                source->priv->compute_movement = g_value_get_boolean (value);
+                break;
+
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         }
@@ -138,7 +149,7 @@ gclue_location_source_class_init (GClueLocationSourceClass *klass)
         gParamSpecs[PROP_LOCATION] = g_param_spec_object ("location",
                                                           "Location",
                                                           "Location",
-                                                          GEOCODE_TYPE_LOCATION,
+                                                          GCLUE_TYPE_LOCATION,
                                                           G_PARAM_READWRITE);
         g_object_class_install_property (object_class,
                                          PROP_LOCATION,
@@ -163,6 +174,18 @@ gclue_location_source_class_init (GClueLocationSourceClass *klass)
         g_object_class_install_property (object_class,
                                          PROP_AVAILABLE_ACCURACY_LEVEL,
                                          gParamSpecs[PROP_AVAILABLE_ACCURACY_LEVEL]);
+
+        gParamSpecs[PROP_COMPUTE_MOVEMENT] =
+                g_param_spec_boolean ("compute-movement",
+                                      "ComputeMovement",
+                                      "Whether or not, speed and heading should "
+                                      "be automatically computed and set on new "
+                                      "locations.",
+                                      TRUE,
+                                      G_PARAM_READWRITE);
+        g_object_class_install_property (object_class,
+                                         PROP_COMPUTE_MOVEMENT,
+                                         gParamSpecs[PROP_COMPUTE_MOVEMENT]);
 }
 
 static void
@@ -172,6 +195,7 @@ gclue_location_source_init (GClueLocationSource *source)
                 G_TYPE_INSTANCE_GET_PRIVATE (source,
                                              GCLUE_TYPE_LOCATION_SOURCE,
                                              GClueLocationSourcePrivate);
+        source->priv->compute_movement = TRUE;
 }
 
 static gboolean
@@ -246,7 +270,7 @@ gclue_location_source_stop (GClueLocationSource *source)
  *
  * Returns: (transfer none): The location, or NULL if unknown.
  **/
-GeocodeLocation *
+GClueLocation *
 gclue_location_source_get_location (GClueLocationSource *source)
 {
         g_return_val_if_fail (GCLUE_IS_LOCATION_SOURCE (source), NULL);
@@ -263,21 +287,49 @@ gclue_location_source_get_location (GClueLocationSource *source)
  **/
 void
 gclue_location_source_set_location (GClueLocationSource *source,
-                                    GeocodeLocation     *location)
+                                    GClueLocation       *location)
 {
         GClueLocationSourcePrivate *priv = source->priv;
+        GClueLocation *cur_location;
+        GeocodeLocation *gloc;
+        gdouble speed, heading;
 
-        if (priv->location == NULL)
-                priv->location = g_object_new (GEOCODE_TYPE_LOCATION, NULL);
+        gloc = GEOCODE_LOCATION (location);
+        cur_location = priv->location;
+        priv->location = gclue_location_new_with_description
+                                (geocode_location_get_latitude (gloc),
+                                 geocode_location_get_longitude (gloc),
+                                 geocode_location_get_accuracy (gloc),
+                                 geocode_location_get_description (gloc));
 
-        g_object_set (priv->location,
-                      "latitude", geocode_location_get_latitude (location),
-                      "longitude", geocode_location_get_longitude (location),
-                      "accuracy", geocode_location_get_accuracy (location),
-                      "description", geocode_location_get_description (location),
-                      NULL);
+        speed = gclue_location_get_speed (location);
+        if (speed == GCLUE_LOCATION_SPEED_UNKNOWN) {
+                if (cur_location != NULL && priv->compute_movement) {
+                        guint64 cur_timestamp, timestamp;
+
+                        timestamp = geocode_location_get_timestamp (gloc);
+                        cur_timestamp = geocode_location_get_timestamp
+                                        (GEOCODE_LOCATION (cur_location));
+
+                        if (timestamp != cur_timestamp)
+                                gclue_location_set_speed_from_prev_location
+                                        (priv->location, cur_location);
+                }
+        } else {
+                gclue_location_set_speed (priv->location, speed);
+        }
+
+        heading = gclue_location_get_heading (location);
+        if (heading == GCLUE_LOCATION_HEADING_UNKNOWN) {
+                if (cur_location != NULL && priv->compute_movement)
+                        gclue_location_set_heading_from_prev_location
+                                (priv->location, cur_location);
+        } else {
+                gclue_location_set_heading (priv->location, heading);
+        }
 
         g_object_notify (G_OBJECT (source), "location");
+        g_clear_object (&cur_location);
 }
 
 /**
@@ -307,3 +359,35 @@ gclue_location_source_get_available_accuracy_level (GClueLocationSource *source)
 
         return source->priv->avail_accuracy_level;
 }
+
+/**
+ * gclue_location_source_get_compute_movement
+ * @source: a #GClueLocationSource
+ *
+ * Returns: %TRUE if speed and heading will be automatically computed and set
+ * on new locations, %FALSE otherwise.
+ **/
+gboolean
+gclue_location_source_get_compute_movement (GClueLocationSource *source)
+{
+        g_return_val_if_fail (GCLUE_IS_LOCATION_SOURCE (source), FALSE);
+
+        return source->priv->compute_movement;
+}
+
+/**
+ * gclue_location_source_set_compute_movement
+ * @source: a #GClueLocationSource
+ * @compute: a #gboolean
+ *
+ * Use this to specify whether or not you want @source to automatically compute
+ * and set speed and heading on new locations.
+ **/
+void
+gclue_location_source_set_compute_movement (GClueLocationSource *source,
+                                            gboolean             compute)
+{
+        g_return_if_fail (GCLUE_IS_LOCATION_SOURCE (source));
+
+        source->priv->compute_movement = compute;
+}
