@@ -27,7 +27,6 @@
 #define GCLUE_LOCATION_H
 
 #include <glib-object.h>
-#include <gio/gio.h>
 #include "geocode-glib/geocode-location.h"
 
 G_BEGIN_DECLS
@@ -39,8 +38,6 @@ G_BEGIN_DECLS
 #define GCLUE_IS_LOCATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GCLUE_TYPE_LOCATION))
 #define GCLUE_LOCATION_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GCLUE_TYPE_LOCATION, GClueLocationClass))
 
-#define INVALID_COORDINATE -G_MAXDOUBLE
-
 typedef struct _GClueLocation        GClueLocation;
 typedef struct _GClueLocationClass   GClueLocationClass;
 typedef struct _GClueLocationPrivate GClueLocationPrivate;
@@ -79,23 +76,12 @@ GClueLocation *gclue_location_new (gdouble latitude,
                                    gdouble longitude,
                                    gdouble accuracy);
 
-GClueLocation *gclue_location_new_full
+GClueLocation *gclue_location_new_with_description
                                   (gdouble     latitude,
                                    gdouble     longitude,
                                    gdouble     accuracy,
-                                   gdouble     speed,
-                                   gdouble     heading,
-                                   gdouble     altitude,
-                                   guint64     timestamp,
                                    const char *description);
 
-GClueLocation *gclue_location_create_from_gga
-                                  (const char *gga,
-                                   GError    **error);
-
-GClueLocation *gclue_location_duplicate
-                                  (GClueLocation *location);
-
 void gclue_location_set_speed     (GClueLocation *loc,
                                    gdouble        speed);
 
