@@ -33,6 +33,10 @@
 #include "gclue-3g.h"
 #endif
 
+#if GCLUE_USE_CDMA_SOURCE
+#include "gclue-cdma.h"
+#endif
+
 #if GCLUE_USE_MODEM_GPS_SOURCE
 #include "gclue-modem-gps.h"
 #endif
@@ -66,21 +70,24 @@ enum
 static GParamSpec *gParamSpecs[LAST_PROP];
 
 static void
-set_location (GClueLocator    *locator,
-              GeocodeLocation *location)
+set_location (GClueLocator  *locator,
+              GClueLocation *location)
 {
-        GeocodeLocation *cur_location;
+        GClueLocation *cur_location;
+        GeocodeLocation *gloc, *cur_gloc;
 
         cur_location = gclue_location_source_get_location
                         (GCLUE_LOCATION_SOURCE (locator));
+        gloc = GEOCODE_LOCATION (location);
+        cur_gloc = GEOCODE_LOCATION (cur_location);
 
         g_debug ("New location available");
 
         if (cur_location != NULL &&
-            geocode_location_get_distance_from (location, cur_location) <
-            geocode_location_get_accuracy (location) &&
-            geocode_location_get_accuracy (location) >
-            geocode_location_get_accuracy (cur_location)) {
+            geocode_location_get_distance_from (gloc, cur_gloc) <
+            geocode_location_get_accuracy (gloc) &&
+            geocode_location_get_accuracy (gloc) >
+            geocode_location_get_accuracy (cur_gloc)) {
                 /* We only take the new location if either the previous one
                  * lies outside its accuracy circle or its more or as
                  * accurate as previous one.
@@ -93,22 +100,35 @@ set_location (GClueLocator    *locator,
                                             location);
 }
 
+static gint
+compare_accuracy_level (GClueLocationSource *src_a,
+                        GClueLocationSource *src_b)
+{
+        GClueAccuracyLevel level_a, level_b;
+
+        level_a = gclue_location_source_get_available_accuracy_level (src_a);
+        level_b = gclue_location_source_get_available_accuracy_level (src_b);
+
+        return (level_b - level_a);
+}
+
 static void
 refresh_available_accuracy_level (GClueLocator *locator)
 {
-        GList *node;
         GClueAccuracyLevel new, existing;
 
-        new = GCLUE_ACCURACY_LEVEL_NONE;
-        for (node = locator->priv->sources; node != NULL; node = node->next) {
-                GClueLocationSource *src;
-                GClueAccuracyLevel level;
+        /* Sort the sources according to their accuracy level so that the head
+         * of the list will have the highest level. The goal is to start the
+         * most accurate source first and when all sources are already active
+         * for an app, a second app to get the most accurate location only.
+         */
+        locator->priv->sources = g_list_sort
+                        (locator->priv->sources,
+                         (GCompareFunc) compare_accuracy_level);
+
+        new = gclue_location_source_get_available_accuracy_level
+                        (GCLUE_LOCATION_SOURCE (locator->priv->sources->data));
 
-                src = GCLUE_LOCATION_SOURCE (node->data);
-                level = gclue_location_source_get_available_accuracy_level (src);
-                if (level > new)
-                        new = level;
-        }
         existing = gclue_location_source_get_available_accuracy_level
                         (GCLUE_LOCATION_SOURCE (locator));
 
@@ -125,7 +145,7 @@ on_location_changed (GObject    *gobject,
 {
         GClueLocator *locator = GCLUE_LOCATOR (user_data);
         GClueLocationSource *source = GCLUE_LOCATION_SOURCE (gobject);
-        GeocodeLocation *location;
+        GClueLocation *location;
 
         location = gclue_location_source_get_location (source);
         set_location (locator, location);
@@ -142,7 +162,7 @@ static void
 start_source (GClueLocator        *locator,
               GClueLocationSource *src)
 {
-        GeocodeLocation *location;
+        GClueLocation *location;
 
         g_signal_connect (G_OBJECT (src),
                           "notify::location",
@@ -180,7 +200,7 @@ on_avail_accuracy_level_changed (GObject    *gobject,
             !is_source_active (locator, src)) {
                 start_source (locator, src);
         } else if ((level == GCLUE_ACCURACY_LEVEL_NONE ||
-                    priv->accuracy_level > level) &&
+                    priv->accuracy_level < level) &&
                    is_source_active (locator, src)) {
                 g_signal_handlers_disconnect_by_func (G_OBJECT (src),
                                                       G_CALLBACK (on_location_changed),
@@ -266,12 +286,13 @@ gclue_locator_constructed (GObject *object)
         GClue3G *source = gclue_3g_get_singleton ();
         locator->priv->sources = g_list_append (locator->priv->sources, source);
 #endif
-        if (locator->priv->accuracy_level >= GCLUE_ACCURACY_LEVEL_CITY) {
-                GClueWifi *wifi = gclue_wifi_get_singleton
-                        (locator->priv->accuracy_level);
-                locator->priv->sources = g_list_append (locator->priv->sources,
-                                                        wifi);
-        }
+#if GCLUE_USE_CDMA_SOURCE
+        GClueCDMA *cdma = gclue_cdma_get_singleton ();
+        locator->priv->sources = g_list_append (locator->priv->sources, cdma);
+#endif
+        GClueWifi *wifi = gclue_wifi_get_singleton (locator->priv->accuracy_level);
+        locator->priv->sources = g_list_append (locator->priv->sources,
+                                                wifi);
 #if GCLUE_USE_MODEM_GPS_SOURCE
         GClueModemGPS *gps = gclue_modem_gps_get_singleton ();
         locator->priv->sources = g_list_append (locator->priv->sources, gps);
@@ -348,8 +369,14 @@ gclue_locator_start (GClueLocationSource *source)
 
                 level = gclue_location_source_get_available_accuracy_level (src);
                 if (level > locator->priv->accuracy_level ||
-                    level == GCLUE_ACCURACY_LEVEL_NONE)
+                    level == GCLUE_ACCURACY_LEVEL_NONE) {
+                        g_debug ("Not starting %s (accuracy level: %u). "
+                                 "Requested accuracy level: %u.",
+                                 G_OBJECT_TYPE_NAME (src),
+                                 level,
+                                 locator->priv->accuracy_level);
                         continue;
+                }
 
                 locator->priv->active_sources = g_list_append (locator->priv->active_sources,
                                                                src);
@@ -392,8 +419,20 @@ gclue_locator_stop (GClueLocationSource *source)
 GClueLocator *
 gclue_locator_new (GClueAccuracyLevel level)
 {
+        GClueAccuracyLevel accuracy_level = level;
+
+        if (accuracy_level == GCLUE_ACCURACY_LEVEL_COUNTRY)
+                /* There is no source that provides country-level accuracy.
+                 * Since Wifi (as geoip) source is the best we can do, accuracy
+                 * really is country-level many times from this source and its
+                 * doubtful app (or user) will mind being given slighly more
+                 * accurate location, lets just map this to city-level accuracy.
+                 */
+                accuracy_level = GCLUE_ACCURACY_LEVEL_CITY;
+
         return g_object_new (GCLUE_TYPE_LOCATOR,
-                             "accuracy-level", level,
+                             "accuracy-level", accuracy_level,
+                             "compute-movement", FALSE,
                              NULL);
 }
 
