@@ -90,23 +90,21 @@ gclue_service_location_get_property (GObject    *object,
         {
                 GClueDBusLocation *location;
                 GClueLocation *loc;
-                GVariant *timestamp;
-                guint64 sec, usec;
+                gdouble altitude;
 
                 location = GCLUE_DBUS_LOCATION (object);
-
-                timestamp = gclue_dbus_location_get_timestamp (location);
-                g_variant_get (timestamp, "(tt)", &sec, &usec);
-
-                loc = gclue_location_new_full
+                loc = gclue_location_new_with_description
                         (gclue_dbus_location_get_latitude (location),
                          gclue_dbus_location_get_longitude (location),
                          gclue_dbus_location_get_accuracy (location),
-                         gclue_dbus_location_get_speed (location),
-                         gclue_dbus_location_get_heading (location),
-                         gclue_dbus_location_get_altitude (location),
-                         sec,
                          gclue_dbus_location_get_description (location));
+                gclue_location_set_speed
+                        (loc, gclue_dbus_location_get_speed (location));
+                gclue_location_set_heading
+                        (loc, gclue_dbus_location_get_heading (location));
+                altitude = gclue_dbus_location_get_altitude (location);
+                if (altitude != GEOCODE_LOCATION_ALTITUDE_UNKNOWN)
+                        g_object_set (loc, "altitude", altitude, NULL);
 
                 g_value_take_object (value, loc);
                 break;
@@ -144,7 +142,6 @@ gclue_service_location_set_property (GObject      *object,
                 GClueLocation *loc;
                 gdouble altitude;
                 GeocodeLocation *g_loc;
-                GVariant *timestamp;
 
                 location = GCLUE_DBUS_LOCATION (object);
                 loc = g_value_get_object (value);
@@ -161,12 +158,6 @@ gclue_service_location_set_property (GObject      *object,
                         (location, gclue_location_get_speed (loc));
                 gclue_dbus_location_set_heading
                         (location, gclue_location_get_heading (loc));
-                timestamp = g_variant_new
-                        ("(tt)",
-                         (guint64) geocode_location_get_timestamp (g_loc),
-                         (guint64) 0);
-                gclue_dbus_location_set_timestamp
-                        (location, timestamp);
                 altitude = geocode_location_get_altitude (g_loc);
                 if (altitude != GEOCODE_LOCATION_ALTITUDE_UNKNOWN)
                         gclue_dbus_location_set_altitude (location, altitude);
@@ -193,10 +184,10 @@ gclue_service_location_handle_method_call (GDBusConnection       *connection,
         GDBusInterfaceVTable *skeleton_vtable;
 
         if (!gclue_client_info_check_bus_name (priv->client_info, sender)) {
-                g_dbus_method_invocation_return_error_literal (invocation,
-                                                               G_DBUS_ERROR,
-                                                               G_DBUS_ERROR_ACCESS_DENIED,
-                                                               "Access denied");
+                g_dbus_method_invocation_return_error (invocation,
+                                                       G_DBUS_ERROR,
+                                                       G_DBUS_ERROR_ACCESS_DENIED,
+                                                       "Access denied");
                 return;
         }
 
