@@ -42,7 +42,7 @@ typedef struct _GClueServiceManagerPrivate GClueServiceManagerPrivate;
 
 struct _GClueServiceManager
 {
-        GClueManagerSkeleton parent;
+        GClueDBusManagerSkeleton parent;
 
         /*< private >*/
         GClueServiceManagerPrivate *priv;
@@ -50,13 +50,14 @@ struct _GClueServiceManager
 
 struct _GClueServiceManagerClass
 {
-        GClueManagerSkeletonClass parent_class;
+        GClueDBusManagerSkeletonClass parent_class;
 };
 
 GType gclue_service_manager_get_type (void) G_GNUC_CONST;
 
-GClueServiceManager * gclue_service_manager_new                   (GDBusConnection *connection,
-                                                                   GError         **error);
+GClueServiceManager * gclue_service_manager_new        (GDBusConnection *connection,
+                                                        GError         **error);
+gboolean              gclue_service_manager_get_active (GClueServiceManager *manager);
 
 G_END_DECLS
 
